shill: Rename *ProxyListener to *ProxyDelegate to conform to coding style.

Coding style requires multiple inheritance only from pure interfaces tagged with
the Interface suffix. Chromium style allows Delegate instead of Interface.

After this change, a *ProxyInterface class is the RPC proxy abstraction provided
for unit test purposes, and a *ProxyDelegate can be inherited and implemented by
proxy clients to catch RPC callbacks. For example, ModemProxyInterface is the
interface to a ModemManager.Modem service, implemented concretely for dbus-c++
by the ModemProxy class; all callbacks get rerouted by ModemProxy to a
ModemProxyDelegate.

BUG=chromium-os:19115
TEST=unit tests

Change-Id: I75c4c5c1f256b338e665e77f58972ab75f39490e
Reviewed-on: http://gerrit.chromium.org/gerrit/10562
Tested-by: Darin Petkov <petkov@chromium.org>
Reviewed-by: Paul Stewart <pstew@chromium.org>
Commit-Ready: Darin Petkov <petkov@chromium.org>
diff --git a/modem_cdma_proxy_interface.h b/modem_cdma_proxy_interface.h
index a3d0063..fd95f0e 100644
--- a/modem_cdma_proxy_interface.h
+++ b/modem_cdma_proxy_interface.h
@@ -28,10 +28,10 @@
   virtual const std::string MEID() = 0;
 };
 
-// ModemManager.Modem.CDMA signal listener to be associated with the proxy.
-class ModemCDMAProxyListener {
+// ModemManager.Modem.CDMA signal delegate to be associated with the proxy.
+class ModemCDMAProxyDelegate {
  public:
-  virtual ~ModemCDMAProxyListener() {}
+  virtual ~ModemCDMAProxyDelegate() {}
 
   virtual void OnCDMAActivationStateChanged(
       uint32 activation_state,